#pragma once

#include "problem/transformation.hpp"
#include "problem/problem.hpp"
#include "problem/bbob.hpp"
#include "problem/pbo.hpp"

#include "problem/wmodel.hpp"

#ifdef USING_MKLANDSCAPE
#include "problem/mklandscape/cliqueTreeC.hpp"
#endif

#include "problem/submodular.hpp"
